@@ -4,8 +4,7 @@ use url::Url;
 
 use crate::error::VerifierError;
 use crate::framework::Framework;
-use crate::interface::BeaconOutput;
-use crate::output::{EndpointReport, Output};
+use crate::output::{BeaconOutput, EndpointReport, Output};
 use crate::spec::{Entity, Spec};
 use crate::{utils, Json};
 
@@ -307,6 +306,7 @@ impl Beacon {
 		BeaconOutput {
 			name: self.name,
 			url: self.url,
+			last_updated: chrono::offset::Utc::now().naive_utc(),
 			entities: output.finish(),
 		}
 	}
