@@ -1,11 +1,20 @@
 use std::collections::BTreeMap;
 
+use chrono::{NaiveDateTime};
 use serde::{Deserialize, Serialize};
 use url::Url;
 
 use crate::error::VerifierError;
 use crate::Json;
 
+#[derive(Debug, Clone, Serialize, Deserialize)]
+pub struct BeaconOutput {
+	pub name: String,
+	pub url: Url,
+	pub last_updated: NaiveDateTime,
+	pub entities: BTreeMap<String, Vec<EndpointOutput>>,
+}
+
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct EndpointOutput {
 	pub name: String,
